@@ -20,12 +20,12 @@ def test_lots_of_queries():
     gc.collect()
     objgraph.show_most_common_types()
 
-    print "Starting..."
+    print("Starting...")
 
     for i in range(1000000):
         if i % 25000 == 0:
             # print memory statistic
-            print "Memory usage: %s" % (resource.getrusage(resource.RUSAGE_SELF).ru_maxrss)
+            print("Memory usage: %s" % (resource.getrusage(resource.RUSAGE_SELF).ru_maxrss))
 
         LoadTest.create(k=i, v=i)
 
